@@ -1,12 +1,14 @@
+from discord.message import PartialMessage
 from discord_ui.slash.tools import handle_options
-from .errors import InvalidEvent, OutOfValidRange
+from .errors import InvalidEvent, OutOfValidRange, WrongType
 from .slash.errors import AlreadyDeferred, EphemeralDeletion
 from .slash.types import ContextCommand, SlashCommand, SubSlashCommand
 from .tools import MISSING, setup_logger
 from .http import BetterRoute, jsonifyMessage, send_files
-from .components import ActionRow, Button, LinkButton, SelectMenu, SelectOption
+from .components import ActionRow, Button, ComponentType, LinkButton, SelectMenu, SelectOption, make_component
 
 import discord
+from discord.ext.commands import Bot
 from discord.errors import HTTPException
 from discord.state import ConnectionState
 
@@ -45,13 +47,28 @@ class Interaction():
         self.version: int = data["version"]
         self.data: dict = data["data"]
         """The passed data of the interaction"""
-        self.channel_id: int = data.get("channel_id")
+        self.channel_id: int = int(data.get("channel_id")) if data.get("channel_id") is not None else None
         """The channel-id where the interaction was created"""
-        self.guild_id: int = data.get("guild_id")
+        self.guild_id: int = int(data["guild_id"]) if data.get("guild_id") is not None else None
         """The guild-id where the interaction was created"""
         self.message: Message = message
         """The message of the interaction"""
 
+    @property
+    def guild(self) -> discord.Guild:
+        """The guild where the interaction was created
+        
+        :type: :class:`discord.Guild`
+        """
+        return self._state._get_guild(self.guild_id)
+    @property
+    def channel(self) -> typing.Union[discord.TextChannel, discord.DMChannel]:
+        """The channel where the interaction was created
+        
+        :type: :class:`discord.TextChannel` | :class:`discord.DMChannel`
+        """
+        return self._state.get_channel(self.channel_id)
+
     async def defer(self, hidden=False):
         """This will acknowledge the interaction. This will show the (*Bot* is thinking...) Dialog
 
@@ -291,30 +308,27 @@ class PressedButton(Interaction, Button):
 
 class SlashedCommand(Interaction, SlashCommand):
     """A :class:`~SlashCommand` object that was used"""
-    def __init__(self, client, command: SlashCommand, data, user, channel, guild_ids = None) -> None:
+    def __init__(self, client, command: SlashCommand, data, user, guild_ids = None) -> None:
         Interaction.__init__(self, client._connection, data, user)
         SlashCommand.__init__(self, None, "EMPTY", guild_ids=guild_ids)
         self._json = command.to_dict()
         self.member: discord.Member = user
-        """The user who created the interaciton"""
-        self.channel: discord.TextChannel = channel
         """The channel where the slash command was used"""
         self.guild_ids = guild_ids
 
 class SlashedSubCommand(SlashedCommand, SubSlashCommand):
     """A Sub-:class:`~SlashCommand` command that was used"""
-    def __init__(self, client, command, data, user, channel, guild_ids) -> None:
-        SlashedCommand.__init__(self, client, command, data, user, channel, guild_ids=guild_ids)
+    def __init__(self, client, command, data, user, guild_ids) -> None:
+        SlashedCommand.__init__(self, client, command, data, user, guild_ids=guild_ids)
         SubSlashCommand.__init__(self, None, "EMPTY", "EMPTY")
 
 
 class SlashedContext(Interaction, ContextCommand):
-    def __init__(self, client, command: ContextCommand, data, user, channel, guild_ids = None) -> None:
+    def __init__(self, client, command: ContextCommand, data, user, guild_ids = None) -> None:
         Interaction.__init__(self, client._connection, data, user)
         ContextCommand.__init__(self, None, "EMPTY", guild_ids)
         self._json = command.to_dict()
         self.member: discord.Member = user
-        self.channel: discord.TextChannel = channel
         self.guild_ids = guild_ids
 
 
@@ -345,12 +359,11 @@ async def getResponseMessage(state: ConnectionState, data, user=None, response =
     channel = state.get_channel(int(data["channel_id"]))
     if response and user:
         if data.get("message") is not None and data["message"]["flags"] == 64:
-            try:
-                return ResponseMessage(state=state, channel=channel, data=data, user=user)
-            except:
-                return EphemeralMessage(state=state, channel=channel, data=data["message"])
+            return EphemeralResponseMessage(state=state, channel=channel, data=data, user=user)
         return ResponseMessage(state=state, channel=channel, data=data, user=user)
 
+    if data.get("message") is not None and data["message"]["flags"] == 64:
+        return EphemeralMessage(state=state, channel=channel, data=data["message"])
     return Message(state=state, channel=channel, data=data)
 
 class Message(discord.Message):
@@ -359,6 +372,7 @@ class Message(discord.Message):
         self.__slots__ = discord.Message.__slots__ + ("components", "supressed")
         self._payload = data
 
+        self._state: ConnectionState = None
         super().__init__(state=state, channel=channel, data=data)
         self.components: typing.List[typing.Union[Button, LinkButton, SelectMenu]] = []
         """The components in the message
@@ -393,46 +407,30 @@ class Message(discord.Message):
     def _update_components(self, data):
         """Updates the message components"""
         if data.get("components") is None:
-            return
-        if len(data["components"]) == 0:
             self.components = []
+            return
+        self.components = []
+        if len(data["components"]) == 0:
+            pass
         elif len(data["components"]) > 1:
             # multiple lines
             for componentWrapper in data["components"]:
                 # newline
                 for index, com in enumerate(componentWrapper["components"]):
-                    if com["type"] == 2:
-                        self.components.append(
-                            Button._fromData(com, index == 0)
-                                if "url" not in com else 
-                            LinkButton._fromData(com, index == 0)
-                        )
-                    elif com["type"] == 3:
-                        self.components.append(
-                            SelectMenu._fromData(com)
-                        )
+                    self.components.append(make_component(com, index==0))
         elif len(data["components"][0]["components"]) > 1:
             # All inline
             for index, com in enumerate(data["components"][0]["components"]):
-                if com["type"] == 2:
-                    self.components.append(Button._fromData(com, index == 0) if "url" not in com else LinkButton._fromData(com, index == 0))
-                elif com["type"] == 3:
-                    self.components.append(SelectedMenu._fromData(com))
+                self.components.append(make_component(com, index==0))
         else:
             # One button
-            component_type = int(data["components"][0]["components"][0]["type"])
             component = data["components"][0]["components"][0]
-
-            if component_type == 2:
-                self.components.append(Button._fromData(component) if "url" not in component else LinkButton._fromData(component))
-            elif component_type == 3:
-                self.components.append(SelectedMenu._fromData(component))
-            else:
-                logging.warn("ignoring unknown component type " + str(component_type))
+            self.components.append(make_component(component))
 
     def _update(self, data):
         super()._update(data)
         self._update_components(data)
+        print("updated components", [type(x) for x in self.components])
 
     async def edit(self, *, content=MISSING, embeds=MISSING, attachments=MISSING, suppress=MISSING, 
         delete_after=MISSING, allowed_mentions=MISSING, components=MISSING):
@@ -587,7 +585,8 @@ class Message(discord.Message):
                     if custom_id is not MISSING and btn.custom_id == custom_id:
                         return True
                     return True
-
+            if not isinstance(client, Bot):
+                raise WrongType("client", client, "discord.ext.commands.Bot")
             return (await client.wait_for('button_press' if event_name.lower() == "button" else "menu_select", check=check, timeout=timeout))[0]
         
         raise InvalidEvent(event_name, ["button", "select"])
@@ -653,17 +652,8 @@ class EphemeralComponent(Interaction):
 
 
 class EphemeralMessage(Message):
-    """Represents a hidden (ephemeral) message
-    
-    .. note::
-        
-        You will get this class for a message only if you sent a hidden response
-
-    This class is almost the same as the :class:`~Message` class, but you can't edit, delete or reply to the message
-    
-    If you want to "reply" to id, use the `interaction.send` method instead
-    """
-    def __init__(self, *, state, channel, data, application_id=MISSING, token=MISSING):
+    """Represents a hidden (ephemeral) message"""
+    def __init__(self, state, channel, data, application_id=MISSING, token=MISSING):
         Message.__init__(self, state=state, channel=channel, data=data)
         self._application_id = application_id
         self._interaction_token = token
@@ -671,4 +661,53 @@ class EphemeralMessage(Message):
         r = BetterRoute("PATCH", f"/webhooks/{self._application_id}/{self._interaction_token}/messages/{self.id}")
         self._update(await self._state.http.request(r, json=jsonifyMessage(**fields)))        
     async def delete(self):
-        raise EphemeralDeletion()
\ No newline at end of file
+        raise EphemeralDeletion()
+
+class EphemeralResponseMessage(ResponseMessage):
+    """A ephemeral message wich was created from an interaction
+    
+    .. important::
+
+        Methods like `.edit()`, which change the original message, need a `token` paremeter passed in order to work
+    """
+    def __init__(self, *, state, channel, data, user):
+        ResponseMessage.__init__(self, state=state, channel=channel, data=data, user=user)
+
+    async def edit(self, token, **fields):
+        """Edits the message
+        
+        Parameters
+        ----------
+            token: :class:`str`
+                The token of the interaction with wich this ephemeral message was sent
+            fields: :class:`kwargs`
+                The fields to edit (ex. `content="...", embed=..., attachments=[...]`)
+
+            Example
+
+            .. code-block::
+
+                async def testing(ctx):
+                    msg = await ctx.send("hello hidden world", components=[Button("test")])
+                    btn = await msg.wait_for(client, "button")
+                    await btn.message.edit(ctx.token, content="edited", components=None)
+        
+        """
+        route = BetterRoute("PATCH", f"/webhooks/{self.interaction.application_id}/{token}/messages/{self.id}")
+        self._update(await self._state.http.request(route, json=jsonifyMessage(**fields)))
+    async def delete(self):
+        raise EphemeralDeletion()
+    async def disable_components(self, token, disable = True):
+        """Disables all component in the message
+        
+        Parameters
+        ----------
+            disable: :class:`bool`, optional
+                Whether to disable (``True``) or enable (``False``) als components; default True
+        
+        """
+        fixed = []
+        for x in self.components:
+            x.disabled = disable
+            fixed.append(x)
+        await self.edit(token, components=fixed)
